yakumo.cinder.v1.snapshot

Package yakumo :: Package cinder :: Package v1 :: Module snapshot |
[hide private]
[frames] | no frames]

# Module snapshot

source code

Resource class and its manager for volumes on Block Storage V1 API

Classes | [hide private]
| Resource resource class for volumes on Block Storage V1 API
| Manager manager class for roles on Block Storage V1 API

Variables | [hide private]
| ATTRIBUTE_MAPPING = ``[``(``'``id``'``,` `'``id``'``,` <yakumo.mapper.NoopClass obj`...``
| __package__ = ``'``yakumo.cinder.v1``'``

Variables Details | [hide private]

  ### ATTRIBUTE_MAPPING Value:
      [('id', 'id', mapper.Noop), ('name', 'display_name', mapper.Noop), ('d
      escription', 'display_description', mapper.Noop), ('size', 'size', map
      per.Noop), ('status', 'status', mapper.Noop), ('source', 'volume_id',
      mapper.Resource('cinder.volume')), ('progress', 'os-extended-snapshot-
      attributes:progress', mapper.Noop), ('project', 'os-extended-snapshot-
      attributes:project_id', mapper.Resource('project')), ('metadata', 'met
      adata', mapper.Noop), ('created_at', 'created_at', mapper.DateTime), (
      'updated_at', 'updated_at', mapper.DateTime),]